[−][src]Enum serde_hjson::error::ErrorCode
The errors that can arise while parsing a JSON stream.
Variants
Custom(String)Catchall for syntax error messages
InvalidType(Type)Incorrect type from value
InvalidValue(String)Incorrect value
InvalidLength(usize)Invalid length
UnknownVariant(String)Unknown variant in an enum.
UnknownField(String)Unknown field in struct.
MissingField(&'static str)Struct is missing a field.
EOFWhileParsingListEOF while parsing a list.
EOFWhileParsingObjectEOF while parsing an object.
EOFWhileParsingStringEOF while parsing a string.
EOFWhileParsingValueEOF while parsing a JSON value.
ExpectedColonExpected this character to be a ':'.
ExpectedListCommaOrEndExpected this character to be either a ',' or a ].
ExpectedObjectCommaOrEndExpected this character to be either a ',' or a }.
ExpectedSomeIdentExpected to parse either a true, false, or a null.
ExpectedSomeValueExpected this character to start a JSON value.
InvalidEscapeInvalid hex escape code.
InvalidNumberInvalid number.
InvalidUnicodeCodePointInvalid unicode code point.
KeyMustBeAStringObject key is not a string.
LoneLeadingSurrogateInHexEscapeLone leading surrogate in hex escape.
TrailingCharactersJSON has non-whitespace trailing characters after the value.
UnexpectedEndOfHexEscapeUnexpected end of hex excape.
PunctuatorInQlStringFound a punctuator character when expecting a quoteless string.